<?php
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

require 'vendor/PHPMailer/PHPMailer.php';
require 'vendor/PHPMailer/SMTP.php';
require 'vendor/PHPMailer/Exception.php';

header('Content-Type: application/json');
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Allow-Headers: Content-Type, Authorization");

// Include the config file to get the database connection
include 'config.php';

// Establish the connection
$conn = connect(); // Initialize the $conn variable with the connection

// Ensure the connection is established
if ($conn === null) {
    echo json_encode(["success" => false, "message" => "Database connection failed"]);
    http_response_code(500);
    exit();
}

$data = json_decode(file_get_contents("php://input"), true);

// Check if the transactionId is present in the request
if (!isset($data['trxref']) || empty($data['trxref'])) {
    echo json_encode(["success" => false, "message" => "Transaction ID is required"]);
    http_response_code(400); // Bad Request
    exit();
}

$transactionId = $data['trxref'];

// Check if email, planName, and amount are set, else use defaults or null
$transactionEmail = isset($data['email']) ? $data['email'] : null;
$planName = isset($data['planName']) ? $data['planName'] : 'Unknown Plan'; // Default to 'Unknown Plan'
$amount = isset($data['amount']) ? $data['amount'] : 0; // Default to 0

// Debug output to check email value
if (!$transactionEmail || !filter_var($transactionEmail, FILTER_VALIDATE_EMAIL)) {
    echo json_encode(["success" => false, "message" => "Invalid or missing email address"]);
    http_response_code(400); // Bad Request
    exit();
}

// Initialize Paystack and verify the payment
$paystackSecretKey = 'sk_test_8006cb95b26563ff895f84e2453b40e2e025e390'; // Replace with your secret key
$paystackUrl = "https://api.paystack.co/transaction/verify/$transactionId";

// cURL request to Paystack API to verify the transaction
$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $paystackUrl);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    "Authorization: Bearer $paystackSecretKey"
]);

$response = curl_exec($ch);

// Handle cURL errors
if (curl_errno($ch)) {
    echo json_encode(["success" => false, "message" => "Paystack verification failed: " . curl_error($ch)]);
    http_response_code(500); // Internal Server Error
    exit();
}

curl_close($ch);

// Log the full Paystack response for debugging purposes
$responseData = json_decode($response, true);
file_put_contents('paystack_response.json', json_encode($responseData, JSON_PRETTY_PRINT));

// Check if Paystack's response is successful
if (isset($responseData['status']) && $responseData['status'] == 'success') {
    $transactionDetails = $responseData['data'];
    $transactionEmail = $transactionDetails['customer']['email'];
    $amountPaid = $transactionDetails['amount'] / 100;  // Convert kobo to naira
    $transactionId = $transactionDetails['reference'];

    // Extract the plan name correctly from the response structure
   $planName = isset($transactionDetails['metadata']['planName']) ? $transactionDetails['metadata']['planName'] : 'Unknown Plan';

    // Debugging: Output plan name to ensure it is correctly set
    echo "Plan Name: " . $planName;  // You can remove this once debugging is done

    $paidAt = $transactionDetails['paid_at'];

    // Database Update Logic
    $updatePaymentQuery = "INSERT INTO payments (user_email, plan_name, amount, transaction_id, created_at) 
                            VALUES (?, ?, ?, ?, NOW())";
    $stmt = $conn->prepare($updatePaymentQuery);
    $stmt->bind_param("ssds", $transactionEmail, $planName, $amountPaid, $transactionId);

    if ($stmt->execute()) {
        // Update payment status in users table
        $updateUserQuery = "UPDATE users SET payment_status = 'paid' WHERE email = ?";
        $stmt = $conn->prepare($updateUserQuery);
        $stmt->bind_param("s", $transactionEmail);

        if ($stmt->execute()) {
            $mail = new PHPMailer(true);
            try {
                // SMTP settings (Brevo or any other SMTP service)
                $mail->isSMTP();
                $mail->Host = 'smtp-relay.brevo.com';
                $mail->SMTPAuth = true;
                $mail->Username = 'ddegreeproject@gmail.com';
                $mail->Password = 'xsmtpsib-d219e2013a5ce1bf42ada0609e149db7e26554fb5f13d446ddf4e891909d4291-4YxQIdg7053fpGkM';
                $mail->SMTPSecure = PHPMailer::ENCRYPTION_STARTTLS;
                $mail->Port = 587;

                // Recipients
                $mail->setFrom('no-reply@imcn.ng', 'IMCN | Nigeria');
                $mail->addAddress($transactionEmail); // Send confirmation to the transaction email

                $mail->isHTML(true);
                $mail->Subject = "Payment Confirmation - $planName Plan";
                $mail->Body = "<h1>Payment Successful</h1>
                                <p>Dear Customer,</p>
                                <p>We have successfully received your payment for the <strong>$planName</strong> plan.</p>
                                <p>Amount Paid: $amountPaid Naira</p>
                                <p>Transaction ID: $transactionId</p>
                                <p>Thank you for your support!</p>";

                $mail->send();
                echo json_encode(["success" => true, "message" => "Payment successfully verified, payment status updated, and email sent"]);
                http_response_code(200); // OK
            } catch (Exception $e) {
                echo json_encode(["success" => false, "message" => "Payment verified but email sending failed: " . $mail->ErrorInfo]);
                http_response_code(500); // Internal Server Error
            }
        } else {
            echo json_encode(["success" => false, "message" => "Failed to update payment status in the users table"]);
            http_response_code(500); // Internal Server Error
        }
    } else {
        echo json_encode(["success" => false, "message" => "Failed to record payment"]);
        http_response_code(500); // Internal Server Error
    }
} else {
    // Handle case where Paystack response status is not 'success'
    echo json_encode(["success" => false, "message" => "Payment verification failed: " . ($responseData['message'] ?? 'Unknown error')]);
    http_response_code(400); // Bad Request
}
?>